@@ -42,6 +42,11 @@ static cfgStruct weex_config[]={
 	{ "LoginName",		CFG_STRING,	&login_name		},
 	{ "AuthorizationName",	CFG_STRING,	&authorization_name	},
 	{ "Password",		CFG_STRING,	&password		},
+#ifdef USE_SSL
+	{ "UseSSL",		CFG_BOOL,	&host_use_SSL		},
+	{ "UseSSLVerify",	CFG_BOOL,	&host_use_SSL_verify	},
+	{ "UseSSLcafile",	CFG_STRING,	&host_use_SSL_cafile	},
+#endif
 	{ "SrcDir",		CFG_STRING,	&src_dir		},
 	{ "DestDir",		CFG_STRING,	&dest_dir		},
 	{ "IgnoreLocalDir",	CFG_STRING_LIST,&ignore_local_dir	},
@@ -191,6 +196,14 @@ void set_default(int max_hosts)
 		set_str_default(i,default_num,login_name);
 		set_str_default(i,default_num,authorization_name);
 		set_str_default(i,default_num,password);
+#ifdef USE_SSL
+		set_bool_default(i,default_num,0,host_use_SSL);
+		set_bool_default(i,default_num,1,host_use_SSL_verify);
+		set_str_default(i,default_num,host_use_SSL_cafile);
+		if (host_use_SSL_cafile[i] == NULL) {
+			host_use_SSL_cafile[i] = DEFAULT_CAFILE;
+		}
+#endif
 		set_str_default(i,default_num,src_dir);
 		set_str_default(i,default_num,dest_dir);
 		set_str_default(i,default_num,change_permission);
@@ -370,10 +383,11 @@ void list_attach_slash_to_trailing(int host,cfgList **list_pointer)
 {
 	cfgList *l;
 
-	if(list_pointer[host]==NULL){
+	l=list_pointer[host];
+	if(l==NULL || l->str==NULL){
 		return;
-	}
-	for(l=list_pointer[host];l!=NULL;l=l->next){
+	}	
+	for(;l!=NULL;l=l->next){
 		if(*(l->str+strlen(l->str)-1)!='/'){
 			l->str=str_realloc(l->str,strlen(l->str)+2);
 			strcat(l->str,"/");
@@ -395,10 +409,11 @@ void absolutize_path(int host,char *base_dir,cfgList **list_absolute_path)
 	cfgList *l;
 	char *temp;
 
-	if(list_absolute_path[host]==NULL){
+	l=list_absolute_path[host];
+	if(l==NULL || l->str==NULL){
 		return;
 	}
-	for(l=list_absolute_path[host];l!=NULL;l=l->next){
+	for(;l!=NULL;l=l->next){
 		if(strcmp(l->str,"./")==0){
 			temp=l->str;
 			l->str=str_dup(base_dir);
